@@ -140,8 +140,6 @@
 #'   \item Wagenmakers, E. J. (2007). A practical solution to the pervasive problems of p values. Psychonomic bulletin & review, 14(5), 779-804.
 #'   \item Wetzels, R., Matzke, D., Lee, M. D., Rouder, J. N., Iverson, G. J., and Wagenmakers, E.-J. (2011). Statistical Evidence in Experimental Psychology: An Empirical Comparison Using 855 t Tests. Perspectives on Psychological Science, 6(3), 291–298. \doi{10.1177/1745691611406923}
 #' }
-#'
-#' @importFrom insight get_response is_model_supported
 #' @export
 bayesfactor_models <- function(..., denominator = 1, verbose = TRUE) {
   UseMethod("bayesfactor_models")
@@ -196,7 +194,6 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 }
 
 
-#' @importFrom insight get_response find_algorithm
 .bayesfactor_models_stan <- function(mods, denominator = 1, verbose = TRUE) {
 
   # Warn
@@ -232,16 +229,15 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
 #' @keywords internal
 .bayesfactor_models_stan_REG <- function(mods, denominator, verbose = TRUE) {
-  if (!requireNamespace("bridgesampling")) {
-    stop("Package 'bridgesampling' required for this function to work. Please install it by running `install.packages('bridgesampling')`.")
-  }
+  insight::check_if_installed("bridgesampling")
 
   # Test that all is good:
   resps <- lapply(mods, insight::get_response)
   from_same_data_as_den <- sapply(resps[-denominator],
-                                  identical,
-                                  y = resps[[denominator]]
+    identical,
+    y = resps[[denominator]]
   )
+
   if (!all(from_same_data_as_den)) {
     stop("Models were not computed from the same data.")
   }
@@ -250,9 +246,11 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   if (verbose) {
     message("Computation of Bayes factors: estimating marginal likelihood, please wait...")
   }
+
   mML <- lapply(mods, function(x) {
     bridgesampling::bridge_sampler(x, silent = TRUE)
   })
+
   mBFs <- sapply(mML, function(x) {
     bf <- bridgesampling::bf(x, mML[[denominator]], log = TRUE)
     bf[["bf"]]
@@ -269,8 +267,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 }
 
 .bayesfactor_models_stan_SEM <- function(mods, denominator, verbose = TRUE) {
-
-  capture.output(
+  utils::capture.output(
     suppressWarnings(
       mBFs <- sapply(mods, function(m) {
         blavaan::blavCompare(m, mods[[denominator]])[["bf"]][1]
@@ -288,9 +285,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
 #' @export
 bayesfactor_models.stanreg <- function(..., denominator = 1, verbose = TRUE) {
-  if (!requireNamespace("rstanarm")) {
-    stop("Package 'rstanarm' required for this function to work. Please install it by running `install.packages('rstanarm')`.")
-  }
+  insight::check_if_installed("rstanarm")
 
   # Organize the models and their names
   mods <- list(...)
@@ -308,12 +303,7 @@ bayesfactor_models.stanreg <- function(..., denominator = 1, verbose = TRUE) {
 
 #' @export
 bayesfactor_models.brmsfit <- function(..., denominator = 1, verbose = TRUE) {
-  if (!requireNamespace("brms")) {
-    stop("Package 'brms' required for this function to work. Please install it by running `install.packages('brms')`.")
-  }
-  if (!("brms" %in% .packages())) {
-    stop("This function requires package 'brms' to be loaded. Please run `library(brms)`.")
-  }
+  insight::check_if_installed("brms")
 
   # Organize the models and their names
   mods <- list(...)
@@ -332,9 +322,7 @@ bayesfactor_models.brmsfit <- function(..., denominator = 1, verbose = TRUE) {
 
 #' @export
 bayesfactor_models.blavaan <- function(..., denominator = 1, verbose = TRUE) {
-  if (!requireNamespace("blavaan")) {
-    stop("Package 'blavaan' required for this function to work. Please install it by running `install.packages('blavaan')`.")
-  }
+  insight::check_if_installed("blavaan")
 
   # Organize the models and their names
   mods <- list(...)
@@ -350,14 +338,12 @@ bayesfactor_models.blavaan <- function(..., denominator = 1, verbose = TRUE) {
   .bayesfactor_models_stan(mods, denominator = denominator, verbose = verbose)
 }
 
-
-
 #' @export
 bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
   models <- c(...)
-  if (!requireNamespace("BayesFactor")) {
-    stop("Package 'BayesFactor' required for this function to work. Please install it by running `install.packages('BayesFactor')`.")
-  }
+
+  insight::check_if_installed("BayesFactor")
+
   mBFs <- c(0, BayesFactor::extractBF(models, TRUE, TRUE))
   mforms <- sapply(c(models@denominator, models@numerator), function(x) x@shortName)
 
@@ -478,7 +464,6 @@ as.matrix.bayesfactor_models <- function(x, ...) {
 
 
 #' @keywords internal
-#' @importFrom insight find_formula
 .find_full_formula <- function(mod) {
   formulas <- insight::find_formula(mod)
 
@@ -499,7 +484,6 @@ as.matrix.bayesfactor_models <- function(x, ...) {
 }
 
 #' @keywords internal
-#' @importFrom stats BIC
 .BIC_list <- function(x) {
   sapply(x, function(m) {
     tryCatch(
