@@ -236,7 +236,6 @@ bayesfactor_parameters.numeric <- function(posterior, prior = NULL, direction =
 }
 
 
-#' @importFrom insight clean_parameters
 #' @rdname bayesfactor_parameters
 #' @export
 bayesfactor_parameters.stanreg <- function(posterior,
@@ -293,7 +292,8 @@ bayesfactor_parameters.blavaan <- function(posterior,
   cleaned_parameters <- insight::clean_parameters(posterior)
 
   samps <- .clean_priors_and_posteriors(posterior, prior,
-                                        verbose = verbose)
+    verbose = verbose
+  )
 
   # Get BFs
   temp <- bayesfactor_parameters.data.frame(
@@ -388,7 +388,6 @@ bayesfactor_parameters.data.frame <- function(posterior,
 
 
 #' @keywords internal
-#' @importFrom insight print_color
 .bayesfactor_parameters <- function(posterior, prior, direction = 0, null = 0, ...) {
   stopifnot(length(null) %in% c(1, 2))
 
@@ -396,10 +395,7 @@ bayesfactor_parameters.data.frame <- function(posterior,
     return(1)
   }
 
-  if (!requireNamespace("logspline")) {
-    stop("Package \"logspline\" needed for this function to work. Please install it.")
-  }
-
+  insight::check_if_installed("logspline")
 
   if (length(null) == 1) {
     relative_density <- function(samples) {
